@@ -23,6 +23,7 @@ from astropy.coordinates import (AltAz, EarthLocation, SkyCoord, get_sun, ICRS,
                 CylindricalRepresentation, CylindricalDifferential,
                 CartesianDifferential)
 from astropy.coordinates.sites import get_builtin_sites
+from astropy.utils.exceptions import ErfaWarning
 from astropy.time import Time
 from astropy.utils import iers
 from astropy.table import Table
@@ -640,3 +641,34 @@ def test_regression_8924():
     with pytest.raises(ValueError):
         rep._re_represent_differentials(CylindricalRepresentation,
                                         {'s2': CylindricalDifferential})
+
+
+def test_regression_10092():
+    """
+    Check that we still get a proper motion even for SkyCoords without distance
+    """
+    c = SkyCoord(l=10*u.degree, b=45*u.degree,
+                 pm_l_cosb=34*u.mas/u.yr, pm_b=-117*u.mas/u.yr,
+                 frame='galactic',
+                 obstime=Time('1988-12-18 05:11:23.5'))
+
+    with pytest.warns(ErfaWarning, match='ERFA function "pmsafe" yielded .*'):
+        # expect ErfaWarning here
+        newc = c.apply_space_motion(dt=10*u.year)
+    assert_quantity_allclose(newc.pm_l_cosb, 33.99980714*u.mas/u.yr,
+                             atol=1.0e-5*u.mas/u.yr)
+
+
+@pytest.mark.parametrize('mjd', (
+    52000, [52000], [[52000]], [52001, 52002], [[52001], [52002]]))
+def test_regression_10422(mjd):
+    """
+    Check that we can get a GCRS for a scalar EarthLocation and a
+    size=1 non-scalar Time.
+    """
+    # Avoid trying to download new IERS data.
+    with iers.earth_orientation_table.set(iers.IERS_B.open(iers.IERS_B_FILE)):
+        t = Time(mjd, format="mjd", scale="tai")
+        loc = EarthLocation(88258.0 * u.m, -4924882.2 * u.m, 3943729.0 * u.m)
+        p, v = loc.get_gcrs_posvel(obstime=t)
+        assert p.shape == v.shape == t.shape
