@@ -6,6 +6,7 @@ import io
 import mmap
 import operator
 import os
+import pathlib
 import platform
 import signal
 import sys
@@ -403,7 +404,7 @@ def fileobj_name(f):
     string f itself is returned.
     """
 
-    if isinstance(f, str):
+    if isinstance(f, (str, bytes)):
         return f
     elif isinstance(f, gzip.GzipFile):
         # The .name attribute on GzipFiles does not always represent the name
@@ -433,7 +434,7 @@ def fileobj_closed(f):
     they are file-like objects with no sense of a 'closed' state.
     """
 
-    if isinstance(f, str):
+    if isinstance(f, (str, pathlib.Path)):
         return True
 
     if hasattr(f, 'closed'):
@@ -680,7 +681,7 @@ def _array_to_file_like(arr, fileobj):
     if hasattr(np, 'nditer'):
         # nditer version for non-contiguous arrays
         for item in np.nditer(arr, order='C'):
-            fileobj.write(item.tostring())
+            fileobj.write(item.tobytes())
     else:
         # Slower version for Numpy versions without nditer;
         # The problem with flatiter is it doesn't preserve the original
@@ -689,10 +690,10 @@ def _array_to_file_like(arr, fileobj):
         if ((sys.byteorder == 'little' and byteorder == '>')
                 or (sys.byteorder == 'big' and byteorder == '<')):
             for item in arr.flat:
-                fileobj.write(item.byteswap().tostring())
+                fileobj.write(item.byteswap().tobytes())
         else:
             for item in arr.flat:
-                fileobj.write(item.tostring())
+                fileobj.write(item.tobytes())
 
 
 def _write_string(f, s):
