@@ -120,18 +120,28 @@ def fitter_unit_support(func):
 
                 if model.input_units is not None:
                     if isinstance(x, Quantity):
-                        x = x.to(model.input_units['x'],
-                                 equivalencies=input_units_equivalencies['x'])
+                        x = x.to(model.input_units[model.inputs[0]],
+                                 equivalencies=input_units_equivalencies[model.inputs[0]])
                     if isinstance(y, Quantity) and z is not None:
-                        y = y.to(model.input_units['y'],
-                                 equivalencies=input_units_equivalencies['y'])
+                        y = y.to(model.input_units[model.inputs[1]],
+                                 equivalencies=input_units_equivalencies[model.inputs[1]])
+
+                # Create a dictionary mapping the real model inputs and outputs
+                # names to the data. This remapping of names must be done here, after
+                # the the input data is converted to the correct units.
+                rename_data = {model.inputs[0]: x}
+                if z is not None:
+                    rename_data[model.outputs[0]] = z
+                    rename_data[model.inputs[1]] = y
+                else:
+                    rename_data[model.outputs[0]] = y
+                    rename_data['z'] = None
 
                 # We now strip away the units from the parameters, taking care to
                 # first convert any parameters to the units that correspond to the
                 # input units (to make sure that initial guesses on the parameters)
                 # are in the right unit system
-                model = model.without_units_for_data(x=x, y=y, z=z)
-
+                model = model.without_units_for_data(**rename_data)
                 # We strip away the units from the input itself
                 add_back_units = False
 
@@ -161,8 +171,7 @@ def fitter_unit_support(func):
 
                 # And finally we add back units to the parameters
                 if add_back_units:
-                    model_new = model_new.with_units_from_data(x=x, y=y, z=z)
-
+                    model_new = model_new.with_units_from_data(**rename_data)
                 return model_new
 
             else:
@@ -393,14 +402,12 @@ class LinearLSQFitter(metaclass=_FitterMeta):
             if hasattr(model_copy, 'domain'):
                 x = self._map_domain_window(model_copy, x)
             if has_fixed:
-                lhs = self._deriv_with_constraints(model_copy,
-                                                   fitparam_indices,
-                                                   x=x)
-                fixderivs = self._deriv_with_constraints(model_copy,
-                                                         fixparam_indices,
-                                                         x=x)
+                lhs = np.asarray(self._deriv_with_constraints(model_copy,
+                                                              fitparam_indices,
+                                                              x=x))
+                fixderivs = self._deriv_with_constraints(model_copy, fixparam_indices, x=x)
             else:
-                lhs = model_copy.fit_deriv(x, *model_copy.parameters)
+                lhs = np.asarray(model_copy.fit_deriv(x, *model_copy.parameters))
             sum_of_implicit_terms = model_copy.sum_of_implicit_terms(x)
             rhs = y
         else:
@@ -411,12 +418,13 @@ class LinearLSQFitter(metaclass=_FitterMeta):
                 x, y = self._map_domain_window(model_copy, x, y)
 
             if has_fixed:
-                lhs = self._deriv_with_constraints(model_copy,
-                                                   fitparam_indices, x=x, y=y)
+                lhs = np.asarray(self._deriv_with_constraints(model_copy,
+                                                              fitparam_indices, x=x, y=y))
                 fixderivs = self._deriv_with_constraints(model_copy,
-                                                         fixparam_indices, x=x, y=y)
+                                                         fixparam_indices,
+                                                         x=x, y=y)
             else:
-                lhs = model_copy.fit_deriv(x, y, *model_copy.parameters)
+                lhs = np.asanyarray(model_copy.fit_deriv(x, y, *model_copy.parameters))
             sum_of_implicit_terms = model_copy.sum_of_implicit_terms(x, y)
 
             if len(model_copy) > 1:
@@ -448,7 +456,7 @@ class LinearLSQFitter(metaclass=_FitterMeta):
         # when constructing their Vandermonde matrix, which can lead to obscure
         # failures below. Ultimately, np.linalg.lstsq can't handle >2D matrices,
         # so just raise a slightly more informative error when this happens:
-        if lhs.ndim > 2:
+        if np.asanyarray(lhs).ndim > 2:
             raise ValueError('{} gives unsupported >2D derivative matrix for '
                              'this x/y'.format(type(model_copy).__name__))
 
@@ -485,9 +493,6 @@ class LinearLSQFitter(metaclass=_FitterMeta):
                 lhs *= weights[:, np.newaxis]
                 rhs = rhs * weights
 
-        if rcond is None:
-            rcond = len(x) * np.finfo(x.dtype).eps
-
         scl = (lhs * lhs).sum(0)
         lhs /= scl
 
@@ -541,7 +546,8 @@ class LinearLSQFitter(metaclass=_FitterMeta):
 
         # TODO: Only Polynomial models currently have an _order attribute;
         # maybe change this to read isinstance(model, PolynomialBase)
-        if hasattr(model_copy, '_order') and rank != model_copy._order:
+        if hasattr(model_copy, '_order') and len(model_copy) == 1 \
+            and not has_fixed and rank != model_copy._order:
             warnings.warn("The fit may be poorly conditioned\n",
                           AstropyUserWarning)
 
@@ -960,7 +966,8 @@ class LevMarLSQFitter(metaclass=_FitterMeta):
 
 class SLSQPLSQFitter(Fitter):
     """
-    SLSQP optimization algorithm and least squares statistic.
+    Sequential Least Squares Programming (SLSQP) optimization algorithm and
+    least squares statistic.
 
 
     Raises
@@ -968,6 +975,10 @@ class SLSQPLSQFitter(Fitter):
     ModelLinearityError
         A linear model is passed to a nonlinear fitter
 
+    Notes
+    ------
+    See also the `~astropy.modeling.optimizers.SLSQP` optimizer.
+
     """
 
     supported_constraints = SLSQP.supported_constraints
@@ -1266,7 +1277,7 @@ def _convert_input(x, y, z=None, n_models=1, model_set_axis=0):
             # be last, so that its first dimension is the same length as the x
             # coordinates.  This is in line with the expectations of
             # numpy.linalg.lstsq:
-            # http://docs.scipy.org/doc/numpy/reference/generated/numpy.linalg.lstsq.html
+            # https://numpy.org/doc/stable/reference/generated/numpy.linalg.lstsq.html
             # That is, each model should be represented by a column.  TODO:
             # Obviously this is a detail of np.linalg.lstsq and should be
             # handled specifically by any fitters that use it...
