@@ -11,7 +11,7 @@ from collections import OrderedDict, defaultdict
 import numpy as np
 
 from astropy.utils.decorators import lazyproperty
-from astropy.utils.exceptions import AstropyWarning, AstropyDeprecationWarning
+from astropy.utils.exceptions import AstropyDeprecationWarning
 from astropy import units as u
 from astropy import _erfa as erfa
 
@@ -129,6 +129,7 @@ class TimeFormat(metaclass=TimeFormatMeta):
     """
 
     _default_scale = 'utc'  # As of astropy 0.4
+    subfmts = ()
 
     def __init__(self, val1, val2, scale, precision,
                  in_subfmt, out_subfmt, from_jd=False):
@@ -215,8 +216,8 @@ class TimeFormat(metaclass=TimeFormatMeta):
         ok1 = (val1.dtype.kind == 'f' and val1.dtype.itemsize >= 8
                and np.all(np.isfinite(val1)) or val1.size == 0)
         ok2 = val2 is None or (
-            val2.dtype.kind == 'f' and val2.dtype.itemsize >= 8 and
-            not np.any(np.isinf(val2))) or val2.size == 0
+            val2.dtype.kind == 'f' and val2.dtype.itemsize >= 8
+            and not np.any(np.isinf(val2))) or val2.size == 0
         if not (ok1 and ok2):
             raise TypeError('Input values for {} class must be finite doubles'
                             .format(self.name))
@@ -292,15 +293,43 @@ class TimeFormat(metaclass=TimeFormatMeta):
         """
         raise NotImplementedError
 
-    def to_value(self, parent=None):
+    def to_value(self, parent=None, out_subfmt=None):
         """
-        Return time representation from internal jd1 and jd2.  This is
-        the base method that ignores ``parent`` and requires that
-        subclasses implement the ``value`` property.  Subclasses that
-        require ``parent`` or have other optional args for ``to_value``
-        should compute and return the value directly.
+        Return time representation from internal jd1 and jd2 in specified
+        ``out_subfmt``.
+
+        This is the base method that ignores ``parent`` and uses the ``value``
+        property to compute the output. This is done by temporarily setting
+        ``self.out_subfmt`` and calling ``self.value``. This is required for
+        legacy Format subclasses prior to astropy 4.0  New code should instead
+        implement the value functionality in ``to_value()`` and then make the
+        ``value`` property be a simple call to ``self.to_value()``.
+
+        Parameters
+        ----------
+        parent : obj
+            Parent `~astropy.time.Time` object associated with this
+            `~astropy.time.TimeFormat` object
+        out_subfmt : str or `None`
+            Output subformt (use existing self.out_subfmt if `None`)
+
+        Returns
+        -------
+        value : numpy.array, numpy.ma.array
+            Array or masked array of formatted time representation values
         """
-        return self.mask_if_needed(self.value)
+        # Get value via ``value`` property, overriding out_subfmt temporarily if needed.
+        if out_subfmt is not None:
+            out_subfmt_orig = self.out_subfmt
+            try:
+                self.out_subfmt = out_subfmt
+                value = self.value
+            finally:
+                self.out_subfmt = out_subfmt_orig
+        else:
+            value = self.value
+
+        return self.mask_if_needed(value)
 
     @property
     def value(self):
@@ -334,18 +363,20 @@ class TimeNumeric(TimeFormat):
         """Input value validation, typically overridden by derived classes"""
         if val1.dtype.kind == 'f':
             val1, val2 = super()._check_val_type(val1, val2)
-        elif (val2 is not None or
-              not (val1.dtype.kind in 'US' or
-                   (val1.dtype.kind == 'O' and
-                    all(isinstance(v, Decimal) for v in val1.flat)))):
+        elif (val2 is not None
+              or not (val1.dtype.kind in 'US'
+                      or (val1.dtype.kind == 'O'
+                          and all(isinstance(v, Decimal) for v in val1.flat)))):
             raise TypeError(
                 'for {} class, input should be doubles, string, or Decimal, '
                 'and second values are only allowed for doubles.'
                 .format(self.name))
 
+        val_dtype = (val1.dtype if val2 is None else
+                     np.result_type(val1.dtype, val2.dtype))
         subfmts = self._select_subfmts(self.in_subfmt)
         for subfmt, dtype, convert, _ in subfmts:
-            if np.issubdtype(val1.dtype, dtype):
+            if np.issubdtype(val_dtype, dtype):
                 break
         else:
             raise ValueError('input type not among selected sub-formats.')
@@ -487,7 +518,7 @@ class TimeDecimalYear(TimeNumeric):
         dt_end = (jd1_end - jd1_start) + (jd2_end - jd2_start)
         decimalyear = iy_start + dt / dt_end
 
-        return super().to_value(jd1=decimalyear, jd2=0., **kwargs)
+        return super().to_value(jd1=decimalyear, jd2=np.float64(0.0), **kwargs)
 
     value = property(to_value)
 
@@ -671,8 +702,8 @@ class TimeStardate(TimeFromEpoch):
     See http://trekguide.com/Stardates.htm#TNG for calculations and reference points
     """
     name = 'stardate'
-    unit = 0.397766856 # Stardate units per day
-    epoch_val = '2318-07-05 11:00:00' # Date and time of stardate 00000.00
+    unit = 0.397766856  # Stardate units per day
+    epoch_val = '2318-07-05 11:00:00'  # Date and time of stardate 00000.00
     epoch_val2 = None
     epoch_scale = 'tai'
     epoch_format = 'iso'
@@ -709,18 +740,47 @@ class TimeAstropyTime(TimeUnique):
 
         if scale is None:
             scale = val1_0.scale
+
         if val1.shape:
             vals = [getattr(val, scale)._time for val in val1]
             jd1 = np.concatenate([np.atleast_1d(val.jd1) for val in vals])
             jd2 = np.concatenate([np.atleast_1d(val.jd2) for val in vals])
+
+            # Collect individual location values and merge into a single location.
+            if any(tm.location is not None for tm in val1):
+                if any(tm.location is None for tm in val1):
+                    raise ValueError('cannot concatenate times unless all locations '
+                                     'are set or no locations are set')
+                locations = []
+                for tm in val1:
+                    location = np.broadcast_to(tm.location, tm._time.jd1.shape,
+                                               subok=True)
+                    locations.append(np.atleast_1d(location))
+
+                # Once we no longer have to support NUMPY_LT_1_17, we can
+                # just write np.concatenate(locations).  Right now, we
+                # effectively do what __array_function__ does directly.
+                location0 = locations[0]
+                unit = location0.unit
+                location = np.concatenate([location.to_value(unit)
+                                           for location in locations])
+                location = location0._new_view(location)
+
+            else:
+                location = None
         else:
             val = getattr(val1_0, scale)._time
             jd1, jd2 = val.jd1, val.jd2
+            location = val1_0.location
 
         OutTimeFormat = val1_0._time.__class__
         self = OutTimeFormat(jd1, jd2, scale, precision, in_subfmt, out_subfmt,
                              from_jd=True)
 
+        # Make a temporary hidden attribute to transfer location back to the
+        # parent Time object where it needs to live.
+        self._location = location
+
         return self
 
 
@@ -772,7 +832,7 @@ class TimeDatetime(TimeUnique):
                               *iterator.operands[1:])
         self.jd1, self.jd2 = day_frac(jd1, jd2)
 
-    def to_value(self, timezone=None, parent=None):
+    def to_value(self, timezone=None, parent=None, out_subfmt=None):
         """
         Convert to (potentially timezone-aware) `~datetime.datetime` object.
 
@@ -789,6 +849,11 @@ class TimeDatetime(TimeUnique):
         `~datetime.datetime`
             If ``timezone`` is not ``None``, output will be timezone-aware.
         """
+        if out_subfmt is not None:
+            # Out_subfmt not allowed for this format, so raise the standard
+            # exception by trying to validate the value.
+            self._select_subfmts(out_subfmt)
+
         if timezone is not None:
             if self._scale != 'utc':
                 raise ScaleValueError("scale is {}, must be 'utc' when timezone "
@@ -888,9 +953,9 @@ class TimeYMDHMS(TimeUnique):
             # Input was empty list [], so set to None and set_jds will handle this
             return None, None
 
-        elif (val1.dtype.kind == 'O' and
-              val1.shape == () and
-              isinstance(val1.item(), dict)):
+        elif (val1.dtype.kind == 'O'
+              and val1.shape == ()
+              and isinstance(val1.item(), dict)):
             # Code gets here for input as a dict.  The dict input
             # can be either scalar values or N-d arrays.
 
@@ -971,7 +1036,7 @@ class TimezoneInfo(datetime.tzinfo):
     a workaround for users without pytz.
     """
     @u.quantity_input(utc_offset=u.day, dst=u.day)
-    def __init__(self, utc_offset=0*u.day, dst=0*u.day, tzname=None):
+    def __init__(self, utc_offset=0 * u.day, dst=0 * u.day, tzname=None):
         """
         Parameters
         ----------
@@ -1083,7 +1148,7 @@ class TimeString(TimeUnique):
                      lambda x: str(x.item(), encoding='ascii'))
         iterator = np.nditer([val1, None, None, None, None, None, None],
                              flags=['zerosize_ok'],
-                             op_dtypes=[None] + 5*[np.intc] + [np.double])
+                             op_dtypes=[None] + 5 * [np.intc] + [np.double])
         for val, iy, im, id, ihr, imin, dsec in iterator:
             val = to_string(val)
             iy[...], im[...], id[...], ihr[...], imin[...], dsec[...] = (
@@ -1389,7 +1454,7 @@ class TimeEpochDate(TimeNumeric):
     def to_value(self, **kwargs):
         jd_to_epoch = getattr(erfa, self.jd_to_epoch)
         value = jd_to_epoch(self.jd1, self.jd2)
-        return super().to_value(jd1=value, jd2=0., **kwargs)
+        return super().to_value(jd1=value, jd2=np.float64(0.0), **kwargs)
 
     value = property(to_value)
 
@@ -1499,7 +1564,7 @@ class TimeDeltaNumeric(TimeDeltaFormat, TimeNumeric):
 
     def set_jds(self, val1, val2):
         self._check_scale(self._scale)  # Validate scale.
-        self.jd1, self.jd2 = day_frac(val1, val2, divisor=1./self.unit)
+        self.jd1, self.jd2 = day_frac(val1, val2, divisor=1. / self.unit)
 
     def to_value(self, **kwargs):
         # Note that 1/unit is always exactly representable, so the
@@ -1546,7 +1611,7 @@ class TimeDeltaDatetime(TimeDeltaFormat, TimeUnique):
         day = datetime.timedelta(days=1)
         for val, jd1, jd2 in iterator:
             jd1[...], other = divmod(val.item(), day)
-            jd2[...] = other/day
+            jd2[...] = other / day
 
         self.jd1, self.jd2 = day_frac(iterator.operands[-2],
                                       iterator.operands[-1])
@@ -1560,7 +1625,7 @@ class TimeDeltaDatetime(TimeDeltaFormat, TimeUnique):
         for jd1, jd2, out in iterator:
             jd1_, jd2_ = day_frac(jd1, jd2)
             out[...] = datetime.timedelta(days=jd1_,
-                                          microseconds=jd2_*86400*1e6)
+                                          microseconds=jd2_ * 86400 * 1e6)
 
         return self.mask_if_needed(iterator.operands[-1])
 
@@ -1603,4 +1668,4 @@ def _broadcast_writeable(jd1, jd2):
     return s_jd1, s_jd2
 
 
-from .core import Time, TIME_SCALES, TIME_DELTA_SCALES, ScaleValueError
+from .core import Time, TIME_SCALES, TIME_DELTA_SCALES, ScaleValueError  # noqa
