@@ -214,7 +214,7 @@ class QuantityInfo(QuantityInfoBase):
 class Quantity(np.ndarray):
     """A `~astropy.units.Quantity` represents a number with some associated unit.
 
-    See also: http://docs.astropy.org/en/stable/units/quantity.html
+    See also: https://docs.astropy.org/en/stable/units/quantity.html
 
     Parameters
     ----------
@@ -271,7 +271,7 @@ class Quantity(np.ndarray):
     Notes
     -----
     Quantities can also be created by multiplying a number or array with a
-    :class:`~astropy.units.Unit`. See http://docs.astropy.org/en/latest/units/
+    :class:`~astropy.units.Unit`. See https://docs.astropy.org/en/latest/units/
 
     """
     # Need to set a class-level default for _equivalencies, or
@@ -1314,7 +1314,7 @@ class Quantity(np.ndarray):
 
     # These functions need to be overridden to take into account the units
     # Array conversion
-    # http://docs.scipy.org/doc/numpy/reference/arrays.ndarray.html#array-conversion
+    # https://numpy.org/doc/stable/reference/arrays.ndarray.html#array-conversion
 
     def item(self, *args):
         return self._new_view(super().item(*args))
@@ -1375,6 +1375,10 @@ class Quantity(np.ndarray):
         raise NotImplementedError("cannot write Quantities to string.  Write "
                                   "array with q.value.tostring(...).")
 
+    def tobytes(self, order='C'):
+        raise NotImplementedError("cannot write Quantities to string.  Write "
+                                  "array with q.value.tobytes(...).")
+
     def tofile(self, fid, sep="", format="%s"):
         raise NotImplementedError("cannot write Quantities to file.  Write "
                                   "array with q.value.tofile(...)")
