@@ -6,6 +6,7 @@
 #include "astropy_wcs/astropy_wcs.h"
 #include "astropy_wcs/wcslib_wrap.h"
 #include "astropy_wcs/wcslib_tabprm_wrap.h"
+#include "astropy_wcs/wcslib_auxprm_wrap.h"
 #include "astropy_wcs/wcslib_units_wrap.h"
 #include "astropy_wcs/wcslib_wtbarr_wrap.h"
 #include "astropy_wcs/distortion_wrap.h"
@@ -836,6 +837,7 @@ PyInit__wcs(void)
       _setup_str_list_proxy_type(m) ||
       _setup_unit_list_proxy_type(m)||
       _setup_wcsprm_type(m)         ||
+      _setup_auxprm_type(m)         ||
       _setup_tabprm_type(m)         ||
       /* _setup_wtbarr_type(m)         || */
       _setup_distortion_type(m)     ||
